@@ -2,14 +2,12 @@
 from cutty.entrypoints.cli._main import main
 from cutty.entrypoints.cli.cookiecutter import cookiecutter
 from cutty.entrypoints.cli.create import create
+from cutty.entrypoints.cli.import_ import import_
+from cutty.entrypoints.cli.link import link
 from cutty.entrypoints.cli.update import update
 
 
-registercommand = main.command()
-
-registercommand(create)
-registercommand(update)
-registercommand(cookiecutter)
-
+for command in [create, update, link, cookiecutter, import_]:
+    main.add_command(command)
 
 __all__ = ["main"]
